<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Ekran kaydını durdurmak için 
tepsi simgesine tıklayın ya da kısayola yeniden basın</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Kayıt boyunca ekranınızı döndürmeyin</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Kaydediyor</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Kapat (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Panoya kopyala (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekran Alıntısı</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Kayıt başarısız. Lütfen ana dizine kaydedin.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Ekran görüntüsü tamamlandı</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>alan seç</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Şuraya kaydedildi %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Yoksay</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Pano</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Ekran kayıt dosyası kaydediliyor, lütfen bekleyin...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>İşlem sırasında pencere efekti devre dışı bırakıldığı için, kayıt durdurulmalıdır.</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Kaydırma Görüntüsü</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Ekran Görüntülerini Sabitle</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Klasör Aç</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Ekran görüntüsü tamamlandı ve panoya kopyalandı</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Her sorgulama</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Belirtilen Konum</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Kaydet sırasında bir yol ayarla</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Kaydet sırasında yolu değiştir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Ekran Görüntülerini Sabitle</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekran görüntüsü</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Kaydet</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekran görüntüsü</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Kayıt</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Görünüm</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Kayıt tamamlandı</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Şuraya kaydedildi %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Kayıt</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Klasör Aç</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation type="unfinished">Her sorgulama</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Belirtilen Konum</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Kaydet sırasında bir yol ayarla</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Kaydet sırasında yolu değiştir</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ekran Alıntısı %1 saniye içinde başlayacak</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Yardım al.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Sürekli ekran görüntüsü alınamadı.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Kaydırma alanının altına ulaştı</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Azami uzunluğa ulaştı</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>yakalama alanını ayarla</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Fare tekerleğini kaydırın veya kayan bir ekran görüntüsü almak için tıklayın</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Kaydırma hızını yavaşlat</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Geçersiz alan, tıklayın</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Metni buraya gir</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Başlat/Ekran Görüntüsü</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Çıkış/Kaydet</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Boyut Ayarı</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Hızlı başlat</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Pencere ekran görüntüsü</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Gecikmeli ekran görüntüsü</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Tam ekran görüntüsü</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kaydet</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Dikdörtgen</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Çizgi</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kalem</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Metin</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Geri al</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Yüksekliği artır</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Yüksekliği azalt</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Sol genişliği artır</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Sağ genişliği artır</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Yüksekliği artır</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Yüksekliği azalt</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Sol genişliği azalt</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Sağ genişliği azalt</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları görüntüle</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Vuruş</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Ekran kaydını başlat</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Kaydı/Başlat</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Fare</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Araçlar</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Metni çıkar</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Kaydırma Görüntüsü</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Ekran görüntülerini sabitle</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>OCR&apos;yi başlat</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Kaydırma Görüntüsü başlat</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>ok</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Kaydet</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Dikdörtgen
Kare çizmek için Shift tuşunu basılı tutun</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elips
Bir daire çizmek için Shift tuşunu basılı tutun</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Fırça
Düz bir çizgi çizmek için Shift tuşunu basılı tutun</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Bulanıklaştırma gücünü ayarlayın (Ayarlamak için kaydırın)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Fırça boyutunu ayarlayın (Ayarlamak için kaydırın)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Metin boyutunu ayarlayın (Ayarlamak için kaydırın)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Tuş Vuruşunu Göster (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Tuş Vuruşunu Gizle (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Tuş Vuruşunu Göster (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Kameraya dön (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Kamerayı kapat (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekran Görüntüsü</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Ayarlar (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Biçim:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ses</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Sistem sesi</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>İşaretçiyi göster</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Tıklamayı göster</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Şuraya kaydet</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videoalar</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Çizgi (L)
Dikey veya yatay çizgi çizmek için Shift tuşunu basılı tutun</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Ok (X)
Dikey veya yatay ok çizmek için Shift tuşunu basılı tutun</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Kalem (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Blur (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Metin (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Kaydırma Görüntüsü (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Metni ayıkla (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Ekran görüntülerini sabitle (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Geri Al (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Kayıt</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Kaydet sırasında yolu değiştir</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Kenar Efektleri</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hiçbiri</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Gölge</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Sınır</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Aygıt</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Metni Çıkar</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Geometrik Araçlar (R)
Kare veya daire çizmek için Shift tuşunu basılı tutun.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Yerel olarak kaydet</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>%1&apos;e kaydet</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Belirtilen Konum</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Kaydet sırasında yolu değiştir</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Kaydet sırasında bir yol ayarla</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Kapat (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>Panoya kopyala (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>Tamam Enter</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Daha iyi video efekti elde etmek için kayıt alanını %1*%2 içinde ayarlayın</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Ekran kaydı şu anda desteklenmiyor</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıkış</translation>
    </message>
</context>
</TS>
